@@ -7,8 +7,8 @@ import cvxopt.solvers as solvers
 from matplotlib import pyplot as plt
 import numpy as np
 from multiprocessing import Pool
-from src import pmo
-from src import dadosgerais
+from src.PyHydro import pmo
+from src.PyHydro import dadosgerais
 from functools import partial
 from timeit import default_timer as timer
 
