@@ -1,4 +1,4 @@
-from src import mddh
+from src.PyHydro import mddh
 import os
 
 sistema = mddh(os.path.join(os.getcwd(), 'pmo/'))
