@@ -1,9 +1,9 @@
 import struct
-from src import hidr
-from src import term
-from src import resequiv
-from src import submercado as subsist
-from src import interc
+from src.PyHydro import hidr
+from src.PyHydro import term
+from src.PyHydro import resequiv
+from src.PyHydro import submercado as subsist
+from src.PyHydro import interc
 import numpy as np
 
 class pmo(object):
